#async-downloads {
    font-size: large;
}

#async-downloads.in-progress #async-downloads-icon {
    animation: pulse 2s infinite;
}

@keyframes pulse {
	0% {
		color: #aaaaaa;
	}

	50% {
        color: white;
	}

	100% {
		color: #aaaaaa;
	}
}

#async-downloads #downloads-dropdown {
    overflow-x: hidden;
    overflow-y: auto;
    max-height: 50vh;
    min-width: 300px;
}

#async-downloads .download-container {
    white-space: nowrap;
    padding: 16px;
}

#async-downloads .download-container:hover {
    background-color: #f7f7f7;
}

#async-downloads .download {
    display: inline-grid;
    width: calc(100% - 22px);
}

#async-downloads .download-name {
    text-overflow: ellipsis;
    overflow-x: hidden;
}

#async-downloads .download-name:hover {
    cursor: pointer;
}

#async-downloads .download-timestamp {
    color: #6c757d !important;
    font-size: small;
}

#async-downloads .download-clear {
    color: #6c757d;
}

#async-downloads .download-clear:hover {
    cursor: pointer;
    color: #4c555d;
}
