{% load i18n %}

<li id="async-downloads" class="nav-item dropdown">
    <a class="nav-link" href="#" id="navbarDropdownAsyncDownloads" role="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
        <span id="async-downloads-icon">
            <i class="fas fa-arrow-alt-circle-down"></i>
        </span>
    </a>
    <div id="downloads-dropdown" class="dropdown-menu dropdown-menu-right" aria-labelledby="navbarDropdownAsyncDownloads">
        <a class="dropdown-item" href="">{% trans "No downloads" %}</a>
    </div>
</li>
